RANDOM_SEED = 42
N_SAMPLE = 1000
ERROR_THRESHOLD = .5
NUM_FEATURES = 6

TREATMENT_COL = 'treatment'
SCORE_COL = 'score'
GROUP_COL = 'group'
OUTCOME_COL = 'outcome'

CONTROL_NAME = 'control'
TREATMENT_NAMES = [CONTROL_NAME, 'treatment1', 'treatment2', 'treatment3']
CONVERSION = 'conversion'
